@@ -24,8 +24,6 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any
 
 from airflow.configuration import conf
-from airflow.models import BaseOperator, XCom
-from airflow.providers.common.compat.version_compat import AIRFLOW_V_3_0_PLUS
 from airflow.providers.dbt.cloud.hooks.dbt import (
     DbtCloudHook,
     DbtCloudJobRunException,
@@ -34,16 +32,16 @@ from airflow.providers.dbt.cloud.hooks.dbt import (
 )
 from airflow.providers.dbt.cloud.triggers.dbt import DbtCloudRunJobTrigger
 from airflow.providers.dbt.cloud.utils.openlineage import generate_openlineage_events_from_dbt_cloud_run
+from airflow.providers.dbt.cloud.version_compat import (
+    BaseOperator,
+    BaseOperatorLink,
+    XCom,
+)
 
 if TYPE_CHECKING:
     from airflow.providers.openlineage.extractors import OperatorLineage
     from airflow.utils.context import Context
 
-if AIRFLOW_V_3_0_PLUS:
-    from airflow.sdk import BaseOperatorLink
-else:
-    from airflow.models.baseoperatorlink import BaseOperatorLink  # type: ignore[no-redef]
-
 
 class DbtCloudRunJobOperatorLink(BaseOperatorLink):
     """Allows users to monitor the triggered job run directly in dbt Cloud."""
@@ -214,30 +212,29 @@ class DbtCloudRunJobOperator(BaseOperator):
                     raise DbtCloudJobRunException(f"Job run {self.run_id} has failed or has been cancelled.")
 
                 return self.run_id
-            else:
-                end_time = time.time() + self.timeout
-                job_run_info = JobRunInfo(account_id=self.account_id, run_id=self.run_id)
-                job_run_status = self.hook.get_job_run_status(**job_run_info)
-                if not DbtCloudJobRunStatus.is_terminal(job_run_status):
-                    self.defer(
-                        timeout=self.execution_timeout,
-                        trigger=DbtCloudRunJobTrigger(
-                            conn_id=self.dbt_cloud_conn_id,
-                            run_id=self.run_id,
-                            end_time=end_time,
-                            account_id=self.account_id,
-                            poll_interval=self.check_interval,
-                        ),
-                        method_name="execute_complete",
-                    )
-                elif job_run_status == DbtCloudJobRunStatus.SUCCESS.value:
-                    self.log.info("Job run %s has completed successfully.", self.run_id)
-                    return self.run_id
-                elif job_run_status in (
-                    DbtCloudJobRunStatus.CANCELLED.value,
-                    DbtCloudJobRunStatus.ERROR.value,
-                ):
-                    raise DbtCloudJobRunException(f"Job run {self.run_id} has failed or has been cancelled.")
+            end_time = time.time() + self.timeout
+            job_run_info = JobRunInfo(account_id=self.account_id, run_id=self.run_id)
+            job_run_status = self.hook.get_job_run_status(**job_run_info)
+            if not DbtCloudJobRunStatus.is_terminal(job_run_status):
+                self.defer(
+                    timeout=self.execution_timeout,
+                    trigger=DbtCloudRunJobTrigger(
+                        conn_id=self.dbt_cloud_conn_id,
+                        run_id=self.run_id,
+                        end_time=end_time,
+                        account_id=self.account_id,
+                        poll_interval=self.check_interval,
+                    ),
+                    method_name="execute_complete",
+                )
+            elif job_run_status == DbtCloudJobRunStatus.SUCCESS.value:
+                self.log.info("Job run %s has completed successfully.", self.run_id)
+                return self.run_id
+            elif job_run_status in (
+                DbtCloudJobRunStatus.CANCELLED.value,
+                DbtCloudJobRunStatus.ERROR.value,
+            ):
+                raise DbtCloudJobRunException(f"Job run {self.run_id} has failed or has been cancelled.")
         else:
             if self.deferrable is True:
                 warnings.warn(
@@ -253,7 +250,7 @@ class DbtCloudRunJobOperator(BaseOperator):
         self.run_id = event["run_id"]
         if event["status"] == "cancelled":
             raise DbtCloudJobRunException(f"Job run {self.run_id} has been cancelled.")
-        elif event["status"] == "error":
+        if event["status"] == "error":
             raise DbtCloudJobRunException(f"Job run {self.run_id} has failed.")
         self.log.info(event["message"])
         return int(event["run_id"])
@@ -284,9 +281,13 @@ class DbtCloudRunJobOperator(BaseOperator):
         """
         from airflow.providers.openlineage.extractors import OperatorLineage
 
-        if isinstance(self.run_id, int) and self.wait_for_termination is True:
-            return generate_openlineage_events_from_dbt_cloud_run(operator=self, task_instance=task_instance)
-        return OperatorLineage()
+        if not isinstance(self.run_id, int):
+            self.log.info("Skipping OpenLineage event extraction: `self.run_id` is not set.")
+            return OperatorLineage()
+        if not self.wait_for_termination:
+            self.log.info("Skipping OpenLineage event extraction: `self.wait_for_termination` is False.")
+            return OperatorLineage()
+        return generate_openlineage_events_from_dbt_cloud_run(operator=self, task_instance=task_instance)
 
 
 class DbtCloudGetJobRunArtifactOperator(BaseOperator):
